@@ -1029,7 +1029,7 @@ class ValiotWorker():
                 # ! Run the frequency job!
                 if self.workerQueueEnabled(queue):
                     if self.queue_locked(queue["name"]):
-                        self.log(LogLevel.ERROR,
+                        self.log(LogLevel.DEBUG,
                                     f"{queue['name']} is LOCKED, postponing...")
                     else:
                         self.gql.mutate(
